@@ -272,7 +272,7 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
             donataria.setAttribute('version', '1.1')
             donataria.setAttribute('noAutorizacion', self.data.get('donataria_no_autorizacion'))
             donataria.setAttribute('fechaAutorizacion', self.data.get('donataria_fecha_autorizacion'))
-            donataria.setAttribute('leyenda', self.data.get('donataria_leyenda'))
+            donataria.setAttribute('leyenda', self.data.get('leyenda'))
             return donataria
         except Exception as e:
             raise Exception("Ocurrio un error al agregar el complemento de Donatarias. Error::: " + str(e))
